@@ -26,12 +26,12 @@
 
 This AWS Solutions Construct deploys a Kinesis Stream and Lambda function with the appropriate resources/properties for interaction and security.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
 ```javascript
-const { KinesisStreamsToLambda } = require('@aws-solutions-constructs/aws-kinesisstreams-lambda');
+const { KinesisStreamsToLambda } from '@aws-solutions-constructs/aws-kinesisstreams-lambda';
 
-new KinesisStreamsToLambda(stack, 'KinesisToLambdaPattern', {
+new KinesisStreamsToLambda(this, 'KinesisToLambdaPattern', {
     eventSourceProps: {
         startingPosition: lambda.StartingPosition.TRIM_HORIZON,
         batchSize: 1
@@ -83,12 +83,14 @@ Out of the box implementation of the Construct without any override will set the
 
 * Configure least privilege access IAM role for Kinesis Stream
 * Enable server-side encryption for Kinesis Stream using AWS Managed KMS Key
+* Deploy best practices CloudWatch Alarms for the Kinesis Stream
 
 ### AWS Lambda Function
 
 * Configure least privilege access IAM role for Lambda function
 * Enable reusing connections with Keep-Alive for NodeJs Lambda function
 * Enable X-Ray Tracing
+* Enable Failure-Handling features like enable bisect on function Error, set defaults for Maximum Record Age (24 hours) & Maximum Retry Attempts (500) and deploy SQS dead-letter queue as destination on failure
 
 ## Architecture
 
@@ -111,10 +113,10 @@ import typing_extensions
 
 from ._jsii import *
 
-import aws_cdk.aws_iam
+import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_lambda
-import aws_cdk.aws_lambda_event_sources
+import aws_cdk.aws_sqs
 import aws_cdk.core
 
 
@@ -124,8 +126,7 @@ class KinesisStreamsToLambda(
     jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambda",
 ):
     """
-    summary:
-    :summary:: The KinesisStreamsToLambda class.
+    :summary: The KinesisStreamsToLambda class.
     """
 
     def __init__(
@@ -133,48 +134,51 @@ class KinesisStreamsToLambda(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
+        deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-        kinesis_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.KinesisEventSourceProps] = None,
+        kinesis_event_source_props: typing.Any = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
+        :param deploy_sqs_dlq_queue: Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue. Default: - true.
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_event_source_props: Optional user-provided props to override the default props for the Lambda event source mapping. Default: - Default props are used.
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
+        :param sqs_dlq_queue_props: Optional user provided properties for the SQS dead letter queue. Default: - Default props are used
 
-        access:
-        :access:: public
-        since:
-        :since:: 0.8.0
-        summary:
-        :summary:: Constructs a new instance of the KinesisStreamsToLambda class.
+        :access: public
+        :since: 0.8.0
+        :summary: Constructs a new instance of the KinesisStreamsToLambda class.
         """
         props = KinesisStreamsToLambdaProps(
+            deploy_sqs_dlq_queue=deploy_sqs_dlq_queue,
             existing_lambda_obj=existing_lambda_obj,
             existing_stream_obj=existing_stream_obj,
             kinesis_event_source_props=kinesis_event_source_props,
             kinesis_stream_props=kinesis_stream_props,
             lambda_function_props=lambda_function_props,
+            sqs_dlq_queue_props=sqs_dlq_queue_props,
         )
 
         jsii.create(KinesisStreamsToLambda, self, [scope, id, props])
 
+    @builtins.property # type: ignore
+    @jsii.member(jsii_name="cloudwatchAlarms")
+    def cloudwatch_alarms(self) -> typing.List[aws_cdk.aws_cloudwatch.Alarm]:
+        return jsii.get(self, "cloudwatchAlarms")
+
     @builtins.property # type: ignore
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return jsii.get(self, "kinesisStream")
 
-    @builtins.property # type: ignore
-    @jsii.member(jsii_name="kinesisStreamRole")
-    def kinesis_stream_role(self) -> aws_cdk.aws_iam.Role:
-        return jsii.get(self, "kinesisStreamRole")
-
     @builtins.property # type: ignore
     @jsii.member(jsii_name="lambdaFunction")
     def lambda_function(self) -> aws_cdk.aws_lambda.Function:
@@ -185,38 +189,46 @@ class KinesisStreamsToLambda(
     jsii_type="@aws-solutions-constructs/aws-kinesisstreams-lambda.KinesisStreamsToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
+        "deploy_sqs_dlq_queue": "deploySqsDlqQueue",
         "existing_lambda_obj": "existingLambdaObj",
         "existing_stream_obj": "existingStreamObj",
         "kinesis_event_source_props": "kinesisEventSourceProps",
         "kinesis_stream_props": "kinesisStreamProps",
         "lambda_function_props": "lambdaFunctionProps",
+        "sqs_dlq_queue_props": "sqsDlqQueueProps",
     },
 )
 class KinesisStreamsToLambdaProps:
     def __init__(
         self,
         *,
+        deploy_sqs_dlq_queue: typing.Optional[builtins.bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-        kinesis_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.KinesisEventSourceProps] = None,
+        kinesis_event_source_props: typing.Any = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        sqs_dlq_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         """The properties for the KinesisStreamsToLambda class.
 
+        :param deploy_sqs_dlq_queue: Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue. Default: - true.
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_event_source_props: Optional user-provided props to override the default props for the Lambda event source mapping. Default: - Default props are used.
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis stream. Default: - Default props are used.
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used.
+        :param sqs_dlq_queue_props: Optional user provided properties for the SQS dead letter queue. Default: - Default props are used
         """
-        if isinstance(kinesis_event_source_props, dict):
-            kinesis_event_source_props = aws_cdk.aws_lambda_event_sources.KinesisEventSourceProps(**kinesis_event_source_props)
         if isinstance(kinesis_stream_props, dict):
             kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if isinstance(sqs_dlq_queue_props, dict):
+            sqs_dlq_queue_props = aws_cdk.aws_sqs.QueueProps(**sqs_dlq_queue_props)
         self._values: typing.Dict[str, typing.Any] = {}
+        if deploy_sqs_dlq_queue is not None:
+            self._values["deploy_sqs_dlq_queue"] = deploy_sqs_dlq_queue
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
         if existing_stream_obj is not None:
@@ -227,12 +239,22 @@ class KinesisStreamsToLambdaProps:
             self._values["kinesis_stream_props"] = kinesis_stream_props
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
+        if sqs_dlq_queue_props is not None:
+            self._values["sqs_dlq_queue_props"] = sqs_dlq_queue_props
+
+    @builtins.property
+    def deploy_sqs_dlq_queue(self) -> typing.Optional[builtins.bool]:
+        """Whether to deploy a SQS dead letter queue when a data record reaches the Maximum Retry Attempts or Maximum Record Age, its metadata like shard ID and stream ARN will be sent to an SQS queue.
+
+        :default: - true.
+        """
+        result = self._values.get("deploy_sqs_dlq_queue")
+        return result
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
         """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
-        default
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
@@ -242,19 +264,15 @@ class KinesisStreamsToLambdaProps:
     def existing_stream_obj(self) -> typing.Optional[aws_cdk.aws_kinesis.Stream]:
         """Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.
 
-        default
         :default: - None
         """
         result = self._values.get("existing_stream_obj")
         return result
 
     @builtins.property
-    def kinesis_event_source_props(
-        self,
-    ) -> typing.Optional[aws_cdk.aws_lambda_event_sources.KinesisEventSourceProps]:
+    def kinesis_event_source_props(self) -> typing.Any:
         """Optional user-provided props to override the default props for the Lambda event source mapping.
 
-        default
         :default: - Default props are used.
         """
         result = self._values.get("kinesis_event_source_props")
@@ -264,7 +282,6 @@ class KinesisStreamsToLambdaProps:
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
         """Optional user-provided props to override the default props for the Kinesis stream.
 
-        default
         :default: - Default props are used.
         """
         result = self._values.get("kinesis_stream_props")
@@ -276,12 +293,20 @@ class KinesisStreamsToLambdaProps:
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """User provided props to override the default props for the Lambda function.
 
-        default
         :default: - Default props are used.
         """
         result = self._values.get("lambda_function_props")
         return result
 
+    @builtins.property
+    def sqs_dlq_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+        """Optional user provided properties for the SQS dead letter queue.
+
+        :default: - Default props are used
+        """
+        result = self._values.get("sqs_dlq_queue_props")
+        return result
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
