@@ -8,20 +8,22 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kinesis._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_lambda_event_sources._jsii
+import aws_cdk.aws_sqs._jsii
 import aws_cdk.core._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-kinesisstreams-lambda",
-    "1.64.1",
+    "1.66.0",
     __name__[0:-6],
-    "aws-kinesisstreams-lambda@1.64.1.jsii.tgz",
+    "aws-kinesisstreams-lambda@1.66.0.jsii.tgz",
 )
 
 __all__ = [
